@@ -9,11 +9,17 @@ from lightning_fast.config_factory.config_constructor import Config
 
 class ClientDescriptorBase(metaclass=ABCMeta):
     """
-    此描述符其宿主必须有config属性，此属性是Config的实例，
-    则此描述符的行为是：
-    初始化时传入config
-    赋值时生成连接字符串
-    引用时创建连接
+    描述符需要宿主对象有一个 `config` 属性，该属性是 `Config` 的实例。
+    在初始化时，当将值分配给 `mongodb_name` 属性时，会生成连接字符串。
+    在访问描述符时，将创建一个连接。即：
+    1. 初始化时传入config
+    2. 赋值时生成连接字符串
+    3. 引用时创建连接
+
+    Parameters
+    ----------
+    mongodb_name : str
+    要连接的 MongoDB 实例的名称。
     """
 
     def __init__(self, mongodb_name: str):
@@ -24,7 +30,7 @@ class ClientDescriptorBase(metaclass=ABCMeta):
 
     def __set_name__(self, owner, name):
         """
-        创建此描述符实例的时候, 直接拿宿主的config属性复制到描述符里边。
+        创建此描述符实例的时候, 直接拿宿主的`config.mongodbs`属性复制到描述符`mongodbs_config` 属性。
         """
         try:
             config = getattr(owner, "config")
@@ -40,13 +46,13 @@ class ClientDescriptorBase(metaclass=ABCMeta):
 
     def __set__(self, instance, mongodb_name: str):
         """
-        赋值时直接将配置中的字段名转换为mongodb连接字符串
+        在将值分配给 `mongodb_name` 时，将配置中的字段名转换为 MongoDB 连接字符串。
         """
         self._set_mongodb(mongodb_name)
 
     def __get__(self, instance, owner):
         """
-        引用的时候才会创建client
+        在访问描述符时，将创建一个 MongoDB 客户端。
         """
         if self.mongodb_url is None:
             return self.mongodb_url
@@ -61,6 +67,9 @@ class ClientDescriptorBase(metaclass=ABCMeta):
         pass
 
     def _set_mongodb(self, mongodb_name: str):
+        """
+        当将值分配给 `mongodb_name` 时，将配置中的字段名转换为 MongoDB 连接字符串。
+        """
         if mongodb_name in self.mongodbs_config:
             conf = self.mongodbs_config[mongodb_name]
             if "uri" in conf:
