@@ -4,16 +4,23 @@ from luigi.contrib.hive import HivePartitionTarget
 
 class HiveDtPartitionCheck(luigi.Task):
     """
-    事实上在另一个地方: offline/variant_data_indicators/base_components/util_tasks.py
-    中有类似的一个通用检查hive partition的任务。但是那里的这个类耦合比较严重, 重构留待之后
-    同时继承此类与TaskBase的实现类即可
+    检查某个hive的某个partition(dt)是否存在
 
+    Attributes:
+        hive_path (str): Hive 表的路径。
+        partition (str): 待检查的分区。
     """
 
     hive_path = luigi.Parameter()
     partition = luigi.Parameter()
 
     def run(self):
+        """运行任务，检查指定的分区是否存在。
+
+        Raises:
+            ValueError: 如果分区不存在。
+
+        """
         existed = HivePartitionTarget(
             str(self.hive_path), partition={"dt": self.partition}
         ).exists()
