@@ -15,7 +15,7 @@ class TestLabelEncoder(unittest.TestCase):
         encoders = LocalCToolsCompiler.import_encoders()
         label_encoder = encoders.LabelEncoder()
         one_d_string_vector = encoders.OneDStringVector(self.test_strings)
-        label_encoder.encode_1d(one_d_string_vector, 2)
+        label_encoder.encode_1d(one_d_string_vector)
         print(label_encoder)
 
     def test_encoder_transform(self):
@@ -23,7 +23,7 @@ class TestLabelEncoder(unittest.TestCase):
         encoders = LocalCToolsCompiler.import_encoders()
         label_encoder = encoders.LabelEncoder()
         one_d_string_vector = encoders.OneDStringVector(self.test_strings)
-        label_encoder.encode_1d(one_d_string_vector, 2)
+        label_encoder.encode_1d(one_d_string_vector)
         transform_result = label_encoder.transform_1d(one_d_string_vector, 2)
         self.assertListEqual(self.test_encode_result, list(transform_result))
 
